/**
 * This file demonstrates the ability to get feedback from a group.
 */

#include <stdio.h>
#include <math.h>

#include "hebi_lookup.h"
#include "hebi_mac_address.h"
#include "feedback_print_helpers.c"
#include "lookup_helpers.c"
#include "hebi_util.h"

int main(int argc, char* argv[])
{
  // Try and get the requested group.
  HebiGroupPtr group = getGroupFromArgs(argc, argv);
  if (group == NULL)
  {
    hebiCleanup();
    return -1;
  }

  // Create a group feedback object; this will be filled in during the request.
  HebiGroupFeedbackPtr feedback =
    hebiGroupFeedbackCreate(hebiGroupGetNumberOfModules(group));
  if (feedback == NULL)
  {
    printf("Could not create feedback object!\n");
    hebiReleaseGroup(group);
    hebiCleanup();
    return -1;
  }

  // In a loop, send requests for feedback to the group and wait for responses.
  long timeout_ms = 1000;
  float period_s = 0.25f;
  int i;
  for (i = 0; i < 20; i++)
  {
    if (hebiGroupRequestFeedback(group, feedback, timeout_ms) == 0)
      print_group_feedback(feedback);
    else
      printf("Received no feedback from group!\n");
    hebi_sleep_ms(period_s * 1000);
  }

  // We must release the resources back to the library when done!
  hebiGroupFeedbackDestroy(feedback);
  hebiReleaseGroup(group);
  hebiCleanup();
  return 0;
}
